'use strict';

const Service = require('egg').Service;
const assert = require('assert');
const moment = require('moment');
class ContentService extends Service {
  async create({ title, thumbnail, annex, content, istop, menus, date, annexname, term }) {
    assert(title, '标题不存在');
    assert(thumbnail, '缩略图不存在');
    assert(content, '内容不存在');
    const { Content: model } = this.ctx.model;
    const createAt = moment().format('x');
    let text = content.replace(new RegExp('</?[^>]+>', 'gm'), '');
    text = text.replace('\\s*|\t|\r|\n', '');
    const slug = text.substring(0, 200);
    try {
      const year = date.slice(0, 3) + '年';
      await model.create({ title, slug, thumbnail, annex, content, istop, menus, createAt, year, date, annexname, term, hits: 0 });
      return { errmsg: '', errcode: 0 };
    } catch (error) {
      throw new Error({ errcode: -2001, errmsg: '添加失败' });
    }
  }
  async update({ title, thumbnail, annex, content, istop, menus, date, annexname, term, _id }) {
    assert(_id, 'id不存在');
    const { Content: model } = this.ctx.model;
    let text = content.replace(new RegExp('</?[^>]+>', 'gm'), '');
    text = text.replace('\\s*|\t|\r|\n', '');
    const slug = text.substring(0, 200);
    const year = date.slice(0, 3) + '年';
    try {
      await model.findById(_id).update({ title, slug, thumbnail, annex, content, istop, menus, year, date, annexname, term });
      return { errmsg: '', errcode: 0 };
    } catch (error) {
      throw new Error({ errcode: -2001, errmsg: '修改失败' });
    }
  }
  async del({ id }) {
    assert(id, 'id不存在');
    const { Content: model } = this.ctx.model;
    try {
      await model.findById(id).remove();
      return { errmsg: '', errcode: 0 };
    } catch (error) {
      throw new Error({ errcode: -2001, errmsg: '删除失败' });
    }
  }
  async details({ id }) {
    assert(id, 'id不存在');
    const { Content: model } = this.ctx.model;
    try {
      const res = await model.findById(id);
      const token = Boolean(this.ctx.request.header.authorization);
      if (!token) {
        res.hits++;
        await model.findById(id).update(res);
      }
      return { errmsg: '', errcode: 0, data: res };
    } catch (error) {
      throw new Error({ errcode: -2001, errmsg: '删除失败' });
    }
  }
  async query({ skip, limit, title, code }) {
    const { Content: model } = this.ctx.model;
    const filter = {};
    if (title) filter.title = title;
    // 后续修改字段 columns - menus
    if (code) filter.menus = code;
    let total = 0;
    try {
      let res;
      total = await model.find({ ...filter });
      if (skip && limit) {
        res = await model.find({ ...filter }, { content: false }).skip(Number(skip) * Number(limit)).limit(Number(limit))
          .sort({ date: -1 });
      } else {
        res = await model.find({ ...filter }, { content: false }).sort({ date: -1 });
      }
      return { errmsg: '', errcode: 0, data: res, total: total.length };
    } catch (error) {
      throw new Error({ errcode: -2001, errmsg: '查询失败' });
    }
  }
  // 数据库添加过滤数据方法
  async filepath() {
    const { Content: model } = this.ctx.model;
    try {
      const res = await model.find();
      for (let i = 0; i < res.length; i++) {
        const content = res[i].content;
        let txet = content.replace(new RegExp(/\/files\/images\/\d{6}\//, 'gm'), '/filespath/resource/');
        txet = txet.replace(new RegExp(/JPG/, 'gm'), 'jpg');
        await model.findById(res[i]._id).update({ ...res, content: txet });
      }
      return { errmsg: '', errcode: 0, res };
    } catch (error) {
      throw new Error({ errcode: -2001, errmsg: '删除失败' });
    }
  }
}

module.exports = ContentService;
